
/* Enable debugging codes. */
#undef DEBUG

/* where is jbterm.conf in */
#undef SYSCONFDIR

/* Support 1bpp */
#undef JFB_1BPP

/* Support 2bpp */
#undef JFB_2BPP

/* Support 4bpp */
#undef JFB_4BPP

/* Support 8bpp */
#undef JFB_8BPP

/* Support 15bpp */
#undef JFB_15BPP

/* Support 16bpp */
#undef JFB_16BPP

/* Support 24bpp */
#undef JFB_24BPP

/* Support 32bpp */
#undef JFB_32BPP

/* Support vga16 */
#undef JFB_VGA16FB

/* Support packed pixel */
#undef JFB_PACKED

/* Support pseudo color */
#undef JFB_PSEUDOCOLOR

/* Support direct color */
#undef JFB_DIRECTCOLOR

/* Support true color */
#undef JFB_TRUECOLOR

/* Quit if mmap(mmio) is failed */
#undef JFB_MMIO_CHECK

/* Force 8bit color */
#undef FORCE_8BIT

/* gzip program path */
#undef JFB_GZIP_PATH

/* Color gamma effect */
#undef JFB_COLOR_GAMMA

/* Supprt Dimmer (Screen blank) */
#undef JFB_ENABLE_DIMMER

/* Support reverse video */
#undef JFB_REVERSEVIDEO
